# -*- coding: utf-8 -*-
from .default_consumer import DefaultConsumer


class BufferedConsumer(DefaultConsumer):

    def __init__(self, product_id, data_source_id, server_host, data_parser=None,
                 max_size=500,
                 retry_limit=3, request_timeout=5, retry_backoff_factor=0.25, verify_cert=True):
        super(BufferedConsumer, self).__init__(product_id, data_source_id, server_host,data_parser,
                                               retry_limit, request_timeout, retry_backoff_factor, verify_cert)
        self._events = []
        self._max_size = min(2000, max_size)

    def send(self, message):
        if hasattr(message, 'event_type'):
            request_url = self.endpoints['collect']
            buf = self._events
            buf.append(message)
            if len(buf) >= self._max_size:
                self._flush_event(request_url)
        else:
            request_url = self.endpoints['item']
            messages = [message]
            self.post_data(request_url, messages)

    def _flush_event(self, request_url):
        buf = self._events
        stm = self._data_parse.get_timestamp()
        while buf:
            batch = buf[:self._max_size]
            self.post_data(request_url, batch)
            buf = buf[self._max_size:]
        self._events = buf

    def flush(self):
        request_url = self.endpoints['collect']
        self._flush_event(request_url)



# -*- coding: utf-8 -*-

import requests
import six
import urllib3


class GrowingIOException(Exception):
    """Raised by consumers when unable to send messages.
    This could be caused by a network outage or interruption.
    """
    pass


class GrowingParamException(Exception):
    """Raised by consumers when unable to send messages.
    This could be caused by a param outage or interruption.
    """
    pass


class Consumer(object):

    def __init__(self, product_id, data_source_id, server_host,
                 retry_limit=3,
                 request_timeout=5,
                 retry_backoff_factor=0.25,
                 verify_cert=True):

        if product_id is None:
            raise (GrowingParamException('ProjectId is NULL'))
        elif data_source_id is None:
            raise (GrowingParamException('DataSourceId is NULL'))
        elif server_host is None:
            raise (GrowingParamException('ServerHost is NULL'))

        if server_host[-1] == '/':
            self._server_host = server_host[:-1]
        else:
            self._server_host = server_host

        self._product_id = product_id
        self._data_source_id = data_source_id

        self._verify_cert = verify_cert
        self._request_timeout = request_timeout

        self.endpoints = {
            'collect': '{0}/v3/projects/{1}/collect'.format(server_host, product_id),
            'item': '{0}/projects/{1}/collect/item'.format(server_host, product_id),
        }

        retry_args = {
            "total": retry_limit,
            "backoff_factor": retry_backoff_factor,
            "status_forcelist": set(range(500, 600)),
            "allowed_methods": {"POST"},
        }
        adapter = requests.adapters.HTTPAdapter(
            max_retries=urllib3.Retry(**retry_args),
        )

        self._session = requests.Session()
        self._session.mount('http', adapter)

    def send(self, message):
        pass

    def send_data(self, request_url, data, params=None, headers=None):
        # print(data)
        return self._write_request(request_url, data, params, headers)

    def _write_request(self, request_url, data, params=None, headers=None):
        request_result = False
        try:
            response = self._session.post(
                request_url,
                data=data,
                timeout=self._request_timeout,
                verify=self._verify_cert,
                params=params,
                headers=headers
            )
        except Exception as e:
            six.raise_from(GrowingIOException(e), e)

        try:
            if response.ok: request_result = True
        except ValueError:
            raise GrowingIOException('Cannot interpret GrowingIO server response: {0}'.format(response.text))

        return request_result



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: event_v3.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='event_v3.proto',
  package='com.growingio.database',
  syntax='proto3',
  serialized_options=b'\n\026com.growingio.protobufB\017EventV3Protocol',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0e\x65vent_v3.proto\x12\x16\x63om.growingio.database\"\xc2\n\n\nEventV3Dto\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0e\n\x06gio_id\x18\x03 \x01(\t\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\t\x12\x35\n\nevent_type\x18\x06 \x01(\x0e\x32!.com.growingio.database.EventType\x12\x10\n\x08platform\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x03\x12\x0e\n\x06\x64omain\x18\t \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\r\n\x05query\x18\x0b \x01(\t\x12\r\n\x05title\x18\x0c \x01(\t\x12\x15\n\rreferral_page\x18\r \x01(\t\x12\x1a\n\x12global_sequence_id\x18\x0e \x01(\x03\x12\x19\n\x11\x65vent_sequence_id\x18\x0f \x01(\x05\x12\x15\n\rscreen_height\x18\x10 \x01(\x05\x12\x14\n\x0cscreen_width\x18\x11 \x01(\x05\x12\x10\n\x08language\x18\x12 \x01(\t\x12\x13\n\x0bsdk_version\x18\x13 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x14 \x01(\t\x12\x43\n\textra_sdk\x18\x15 \x03(\x0b\x32\x30.com.growingio.database.EventV3Dto.ExtraSdkEntry\x12\x12\n\nevent_name\x18\x16 \x01(\t\x12\x1b\n\x13page_show_timestamp\x18\x17 \x01(\x03\x12\x46\n\nattributes\x18\x18 \x03(\x0b\x32\x32.com.growingio.database.EventV3Dto.AttributesEntry\x12;\n\rresource_item\x18\x19 \x01(\x0b\x32$.com.growingio.database.ResourceItem\x12\x15\n\rprotocol_type\x18\x1a \x01(\t\x12\x12\n\ntext_value\x18\x1b \x01(\t\x12\r\n\x05xpath\x18\x1c \x01(\t\x12\r\n\x05index\x18\x1d \x01(\x05\x12\x11\n\thyperlink\x18\x1e \x01(\t\x12\x12\n\nurl_scheme\x18\x1f \x01(\t\x12\x11\n\tapp_state\x18  \x01(\t\x12\x15\n\rnetwork_state\x18! \x01(\t\x12\x13\n\x0b\x61pp_channel\x18\" \x01(\t\x12\x11\n\tpage_name\x18# \x01(\t\x12\x18\n\x10platform_version\x18$ \x01(\t\x12\x14\n\x0c\x64\x65vice_brand\x18% \x01(\t\x12\x14\n\x0c\x64\x65vice_model\x18& \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\' \x01(\t\x12\x18\n\x10operating_system\x18( \x01(\t\x12\x10\n\x08\x61pp_name\x18* \x01(\t\x12\x10\n\x08latitude\x18, \x01(\x01\x12\x11\n\tlongitude\x18- \x01(\x01\x12\x0c\n\x04imei\x18. \x01(\t\x12\x12\n\nandroid_id\x18/ \x01(\t\x12\x0c\n\x04oaid\x18\x30 \x01(\t\x12\x1d\n\x15google_advertising_id\x18\x31 \x01(\t\x12\x0c\n\x04idfa\x18\x32 \x01(\t\x12\x0c\n\x04idfv\x18\x33 \x01(\t\x12\x13\n\x0borientation\x18\x34 \x01(\t\x12\x13\n\x0bproject_key\x18\x35 \x01(\t\x12\x11\n\tsend_time\x18\x36 \x01(\x03\x12\x10\n\x08user_key\x18\x37 \x01(\t\x1a/\n\rExtraSdkEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x0cResourceItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12H\n\nattributes\x18\x03 \x03(\x0b\x32\x34.com.growingio.database.ResourceItem.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x0b\x45ventV3List\x12\x32\n\x06values\x18\x01 \x03(\x0b\x32\".com.growingio.database.EventV3Dto*\xd0\x01\n\tEventType\x12\t\n\x05VISIT\x10\x00\x12\n\n\x06\x43USTOM\x10\x01\x12\x16\n\x12VISITOR_ATTRIBUTES\x10\x02\x12\x19\n\x15LOGIN_USER_ATTRIBUTES\x10\x03\x12\x18\n\x14\x43ONVERSION_VARIABLES\x10\x04\x12\x0e\n\nAPP_CLOSED\x10\x05\x12\x08\n\x04PAGE\x10\x06\x12\x13\n\x0fPAGE_ATTRIBUTES\x10\x07\x12\x0e\n\nVIEW_CLICK\x10\x08\x12\x0f\n\x0bVIEW_CHANGE\x10\t\x12\x0f\n\x0b\x46ORM_SUBMIT\x10\nB)\n\x16\x63om.growingio.protobufB\x0f\x45ventV3Protocolb\x06proto3'
)

_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='com.growingio.database.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VISIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISITOR_ATTRIBUTES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGIN_USER_ATTRIBUTES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_VARIABLES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APP_CLOSED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAGE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAGE_ATTRIBUTES', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_CLICK', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIEW_CHANGE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORM_SUBMIT', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1626,
  serialized_end=1834,
)
_sym_db.RegisterEnumDescriptor(_EVENTTYPE)

EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
VISIT = 0
CUSTOM = 1
VISITOR_ATTRIBUTES = 2
LOGIN_USER_ATTRIBUTES = 3
CONVERSION_VARIABLES = 4
APP_CLOSED = 5
PAGE = 6
PAGE_ATTRIBUTES = 7
VIEW_CLICK = 8
VIEW_CHANGE = 9
FORM_SUBMIT = 10



_EVENTV3DTO_EXTRASDKENTRY = _descriptor.Descriptor(
  name='ExtraSdkEntry',
  full_name='com.growingio.database.EventV3Dto.ExtraSdkEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.growingio.database.EventV3Dto.ExtraSdkEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.growingio.database.EventV3Dto.ExtraSdkEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1291,
  serialized_end=1338,
)

_EVENTV3DTO_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='com.growingio.database.EventV3Dto.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.growingio.database.EventV3Dto.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.growingio.database.EventV3Dto.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1389,
)

_EVENTV3DTO = _descriptor.Descriptor(
  name='EventV3Dto',
  full_name='com.growingio.database.EventV3Dto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='com.growingio.database.EventV3Dto.device_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='com.growingio.database.EventV3Dto.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gio_id', full_name='com.growingio.database.EventV3Dto.gio_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='com.growingio.database.EventV3Dto.session_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_id', full_name='com.growingio.database.EventV3Dto.data_source_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='com.growingio.database.EventV3Dto.event_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform', full_name='com.growingio.database.EventV3Dto.platform', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='com.growingio.database.EventV3Dto.timestamp', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='com.growingio.database.EventV3Dto.domain', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='com.growingio.database.EventV3Dto.path', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='com.growingio.database.EventV3Dto.query', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='com.growingio.database.EventV3Dto.title', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referral_page', full_name='com.growingio.database.EventV3Dto.referral_page', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global_sequence_id', full_name='com.growingio.database.EventV3Dto.global_sequence_id', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_sequence_id', full_name='com.growingio.database.EventV3Dto.event_sequence_id', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_height', full_name='com.growingio.database.EventV3Dto.screen_height', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_width', full_name='com.growingio.database.EventV3Dto.screen_width', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='com.growingio.database.EventV3Dto.language', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sdk_version', full_name='com.growingio.database.EventV3Dto.sdk_version', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='com.growingio.database.EventV3Dto.app_version', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_sdk', full_name='com.growingio.database.EventV3Dto.extra_sdk', index=20,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_name', full_name='com.growingio.database.EventV3Dto.event_name', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_show_timestamp', full_name='com.growingio.database.EventV3Dto.page_show_timestamp', index=22,
      number=23, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='com.growingio.database.EventV3Dto.attributes', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_item', full_name='com.growingio.database.EventV3Dto.resource_item', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_type', full_name='com.growingio.database.EventV3Dto.protocol_type', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_value', full_name='com.growingio.database.EventV3Dto.text_value', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xpath', full_name='com.growingio.database.EventV3Dto.xpath', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='com.growingio.database.EventV3Dto.index', index=28,
      number=29, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hyperlink', full_name='com.growingio.database.EventV3Dto.hyperlink', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url_scheme', full_name='com.growingio.database.EventV3Dto.url_scheme', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_state', full_name='com.growingio.database.EventV3Dto.app_state', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_state', full_name='com.growingio.database.EventV3Dto.network_state', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_channel', full_name='com.growingio.database.EventV3Dto.app_channel', index=33,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_name', full_name='com.growingio.database.EventV3Dto.page_name', index=34,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='com.growingio.database.EventV3Dto.platform_version', index=35,
      number=36, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_brand', full_name='com.growingio.database.EventV3Dto.device_brand', index=36,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_model', full_name='com.growingio.database.EventV3Dto.device_model', index=37,
      number=38, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='com.growingio.database.EventV3Dto.device_type', index=38,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operating_system', full_name='com.growingio.database.EventV3Dto.operating_system', index=39,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='com.growingio.database.EventV3Dto.app_name', index=40,
      number=42, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='com.growingio.database.EventV3Dto.latitude', index=41,
      number=44, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='com.growingio.database.EventV3Dto.longitude', index=42,
      number=45, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imei', full_name='com.growingio.database.EventV3Dto.imei', index=43,
      number=46, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='android_id', full_name='com.growingio.database.EventV3Dto.android_id', index=44,
      number=47, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oaid', full_name='com.growingio.database.EventV3Dto.oaid', index=45,
      number=48, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_advertising_id', full_name='com.growingio.database.EventV3Dto.google_advertising_id', index=46,
      number=49, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idfa', full_name='com.growingio.database.EventV3Dto.idfa', index=47,
      number=50, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idfv', full_name='com.growingio.database.EventV3Dto.idfv', index=48,
      number=51, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='com.growingio.database.EventV3Dto.orientation', index=49,
      number=52, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='project_key', full_name='com.growingio.database.EventV3Dto.project_key', index=50,
      number=53, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_time', full_name='com.growingio.database.EventV3Dto.send_time', index=51,
      number=54, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_key', full_name='com.growingio.database.EventV3Dto.user_key', index=52,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVENTV3DTO_EXTRASDKENTRY, _EVENTV3DTO_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=1389,
)


_RESOURCEITEM_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='com.growingio.database.ResourceItem.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='com.growingio.database.ResourceItem.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.growingio.database.ResourceItem.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1389,
)

_RESOURCEITEM = _descriptor.Descriptor(
  name='ResourceItem',
  full_name='com.growingio.database.ResourceItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='com.growingio.database.ResourceItem.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='com.growingio.database.ResourceItem.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='com.growingio.database.ResourceItem.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEITEM_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1556,
)


_EVENTV3LIST = _descriptor.Descriptor(
  name='EventV3List',
  full_name='com.growingio.database.EventV3List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='com.growingio.database.EventV3List.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1558,
  serialized_end=1623,
)

_EVENTV3DTO_EXTRASDKENTRY.containing_type = _EVENTV3DTO
_EVENTV3DTO_ATTRIBUTESENTRY.containing_type = _EVENTV3DTO
_EVENTV3DTO.fields_by_name['event_type'].enum_type = _EVENTTYPE
_EVENTV3DTO.fields_by_name['extra_sdk'].message_type = _EVENTV3DTO_EXTRASDKENTRY
_EVENTV3DTO.fields_by_name['attributes'].message_type = _EVENTV3DTO_ATTRIBUTESENTRY
_EVENTV3DTO.fields_by_name['resource_item'].message_type = _RESOURCEITEM
_RESOURCEITEM_ATTRIBUTESENTRY.containing_type = _RESOURCEITEM
_RESOURCEITEM.fields_by_name['attributes'].message_type = _RESOURCEITEM_ATTRIBUTESENTRY
_EVENTV3LIST.fields_by_name['values'].message_type = _EVENTV3DTO
DESCRIPTOR.message_types_by_name['EventV3Dto'] = _EVENTV3DTO
DESCRIPTOR.message_types_by_name['ResourceItem'] = _RESOURCEITEM
DESCRIPTOR.message_types_by_name['EventV3List'] = _EVENTV3LIST
DESCRIPTOR.enum_types_by_name['EventType'] = _EVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventV3Dto = _reflection.GeneratedProtocolMessageType('EventV3Dto', (_message.Message,), {

  'ExtraSdkEntry' : _reflection.GeneratedProtocolMessageType('ExtraSdkEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVENTV3DTO_EXTRASDKENTRY,
    '__module__' : 'event_v3_pb2'
    # @@protoc_insertion_point(class_scope:com.growingio.database.EventV3Dto.ExtraSdkEntry)
    })
  ,

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVENTV3DTO_ATTRIBUTESENTRY,
    '__module__' : 'event_v3_pb2'
    # @@protoc_insertion_point(class_scope:com.growingio.database.EventV3Dto.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _EVENTV3DTO,
  '__module__' : 'event_v3_pb2'
  # @@protoc_insertion_point(class_scope:com.growingio.database.EventV3Dto)
  })
_sym_db.RegisterMessage(EventV3Dto)
_sym_db.RegisterMessage(EventV3Dto.ExtraSdkEntry)
_sym_db.RegisterMessage(EventV3Dto.AttributesEntry)

ResourceItem = _reflection.GeneratedProtocolMessageType('ResourceItem', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEITEM_ATTRIBUTESENTRY,
    '__module__' : 'event_v3_pb2'
    # @@protoc_insertion_point(class_scope:com.growingio.database.ResourceItem.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEITEM,
  '__module__' : 'event_v3_pb2'
  # @@protoc_insertion_point(class_scope:com.growingio.database.ResourceItem)
  })
_sym_db.RegisterMessage(ResourceItem)
_sym_db.RegisterMessage(ResourceItem.AttributesEntry)

EventV3List = _reflection.GeneratedProtocolMessageType('EventV3List', (_message.Message,), {
  'DESCRIPTOR' : _EVENTV3LIST,
  '__module__' : 'event_v3_pb2'
  # @@protoc_insertion_point(class_scope:com.growingio.database.EventV3List)
  })
_sym_db.RegisterMessage(EventV3List)


DESCRIPTOR._options = None
_EVENTV3DTO_EXTRASDKENTRY._options = None
_EVENTV3DTO_ATTRIBUTESENTRY._options = None
_RESOURCEITEM_ATTRIBUTESENTRY._options = None
# @@protoc_insertion_point(module_scope)
